import pprint
import re  # noqa: F401

import six

class TaskDetails(object):
    """NOTE: This class is auto generated by the swagger code generator program.

    Do not edit the class manually.
    """
    """
    Attributes:
      swagger_types (dict): The key is attribute name
                            and the value is attribute type.
      attribute_map (dict): The key is attribute name
                            and the value is json key in definition.
    """
    swagger_types = {
        'workflow_id': 'str',
        'task_ref_name': 'str',
        'output': 'dict(str, object)',
        'task_id': 'str'
    }

    attribute_map = {
        'workflow_id': 'workflowId',
        'task_ref_name': 'taskRefName',
        'output': 'output',
        'task_id': 'taskId'
    }

    def __init__(self, workflow_id=None, task_ref_name=None, output=None, task_id=None):  # noqa: E501
        """TaskDetails - a model defined in Swagger"""  # noqa: E501
        self._workflow_id = None
        self._task_ref_name = None
        self._output = None
        self._task_id = None
        self.discriminator = None
        if workflow_id is not None:
            self.workflow_id = workflow_id
        if task_ref_name is not None:
            self.task_ref_name = task_ref_name
        if output is not None:
            self.output = output
        if task_id is not None:
            self.task_id = task_id

    @property
    def workflow_id(self):
        """Gets the workflow_id of this TaskDetails.  # noqa: E501


        :return: The workflow_id of this TaskDetails.  # noqa: E501
        :rtype: str
        """
        return self._workflow_id

    @workflow_id.setter
    def workflow_id(self, workflow_id):
        """Sets the workflow_id of this TaskDetails.


        :param workflow_id: The workflow_id of this TaskDetails.  # noqa: E501
        :type: str
        """

        self._workflow_id = workflow_id

    @property
    def task_ref_name(self):
        """Gets the task_ref_name of this TaskDetails.  # noqa: E501


        :return: The task_ref_name of this TaskDetails.  # noqa: E501
        :rtype: str
        """
        return self._task_ref_name

    @task_ref_name.setter
    def task_ref_name(self, task_ref_name):
        """Sets the task_ref_name of this TaskDetails.


        :param task_ref_name: The task_ref_name of this TaskDetails.  # noqa: E501
        :type: str
        """

        self._task_ref_name = task_ref_name

    @property
    def output(self):
        """Gets the output of this TaskDetails.  # noqa: E501


        :return: The output of this TaskDetails.  # noqa: E501
        :rtype: dict(str, object)
        """
        return self._output

    @output.setter
    def output(self, output):
        """Sets the output of this TaskDetails.


        :param output: The output of this TaskDetails.  # noqa: E501
        :type: dict(str, object)
        """

        self._output = output

    @property
    def task_id(self):
        """Gets the task_id of this TaskDetails.  # noqa: E501


        :return: The task_id of this TaskDetails.  # noqa: E501
        :rtype: str
        """
        return self._task_id

    @task_id.setter
    def task_id(self, task_id):
        """Sets the task_id of this TaskDetails.


        :param task_id: The task_id of this TaskDetails.  # noqa: E501
        :type: str
        """

        self._task_id = task_id

    def to_dict(self):
        """Returns the model properties as a dict"""
        result = {}

        for attr, _ in six.iteritems(self.swagger_types):
            value = getattr(self, attr)
            if isinstance(value, list):
                result[attr] = list(map(
                    lambda x: x.to_dict() if hasattr(x, "to_dict") else x,
                    value
                ))
            elif hasattr(value, "to_dict"):
                result[attr] = value.to_dict()
            elif isinstance(value, dict):
                result[attr] = dict(map(
                    lambda item: (item[0], item[1].to_dict())
                    if hasattr(item[1], "to_dict") else item,
                    value.items()
                ))
            else:
                result[attr] = value
        if issubclass(TaskDetails, dict):
            for key, value in self.items():
                result[key] = value

        return result

    def to_str(self):
        """Returns the string representation of the model"""
        return pprint.pformat(self.to_dict())

    def __repr__(self):
        """For `print` and `pprint`"""
        return self.to_str()

    def __eq__(self, other):
        """Returns true if both objects are equal"""
        if not isinstance(other, TaskDetails):
            return False

        return self.__dict__ == other.__dict__

    def __ne__(self, other):
        """Returns true if both objects are not equal"""
        return not self == other



import pprint
import re  # noqa: F401

import six

class CorrelationIdsSearchRequest(object):
    """NOTE: This class is auto generated by the swagger code generator program.

    Do not edit the class manually.
    """
    """
    Attributes:
      swagger_types (dict): The key is attribute name
                            and the value is attribute type.
      attribute_map (dict): The key is attribute name
                            and the value is json key in definition.
    """
    swagger_types = {
        'correlation_ids': 'list[str]',
        'workflow_names': 'list[str]'
    }

    attribute_map = {
        'correlation_ids': 'correlationIds',
        'workflow_names': 'workflowNames'
    }

    def __init__(self, correlation_ids=None, workflow_names=None):  # noqa: E501
        """CorrelationIdsSearchRequest - a model defined in Swagger"""  # noqa: E501
        self._correlation_ids = None
        self._workflow_names = None
        self.discriminator = None
        self.correlation_ids = correlation_ids
        self.workflow_names = workflow_names

    @property
    def correlation_ids(self):
        """Gets the correlation_ids of this CorrelationIdsSearchRequest.  # noqa: E501


        :return: The correlation_ids of this CorrelationIdsSearchRequest.  # noqa: E501
        :rtype: list[str]
        """
        return self._correlation_ids

    @correlation_ids.setter
    def correlation_ids(self, correlation_ids):
        """Sets the correlation_ids of this CorrelationIdsSearchRequest.


        :param correlation_ids: The correlation_ids of this CorrelationIdsSearchRequest.  # noqa: E501
        :type: list[str]
        """
        self._correlation_ids = correlation_ids

    @property
    def workflow_names(self):
        """Gets the workflow_names of this CorrelationIdsSearchRequest.  # noqa: E501


        :return: The workflow_names of this CorrelationIdsSearchRequest.  # noqa: E501
        :rtype: list[str]
        """
        return self._workflow_names

    @workflow_names.setter
    def workflow_names(self, workflow_names):
        """Sets the workflow_names of this CorrelationIdsSearchRequest.


        :param workflow_names: The workflow_names of this CorrelationIdsSearchRequest.  # noqa: E501
        :type: list[str]
        """
        self._workflow_names = workflow_names

    def to_dict(self):
        """Returns the model properties as a dict"""
        result = {}

        for attr, _ in six.iteritems(self.swagger_types):
            value = getattr(self, attr)
            if isinstance(value, list):
                result[attr] = list(map(
                    lambda x: x.to_dict() if hasattr(x, "to_dict") else x,
                    value
                ))
            elif hasattr(value, "to_dict"):
                result[attr] = value.to_dict()
            elif isinstance(value, dict):
                result[attr] = dict(map(
                    lambda item: (item[0], item[1].to_dict())
                    if hasattr(item[1], "to_dict") else item,
                    value.items()
                ))
            else:
                result[attr] = value
        if issubclass(CorrelationIdsSearchRequest, dict):
            for key, value in self.items():
                result[key] = value

        return result

    def to_str(self):
        """Returns the string representation of the model"""
        return pprint.pformat(self.to_dict())

    def __repr__(self):
        """For `print` and `pprint`"""
        return self.to_str()

    def __eq__(self, other):
        """Returns true if both objects are equal"""
        if not isinstance(other, CorrelationIdsSearchRequest):
            return False

        return self.__dict__ == other.__dict__

    def __ne__(self, other):
        """Returns true if both objects are not equal"""
        return not self == other



from copy import deepcopy
from conductor.client.http.models.workflow_task import WorkflowTask
from conductor.client.workflow.task.task import TaskInterface
from conductor.client.workflow.task.task_type import TaskType
from typing_extensions import Self


class EventTaskInterface(TaskInterface):
    def __init__(self, task_ref_name: str, event_prefix: str, event_suffix: str) -> Self:
        super().__init__(
            task_reference_name=task_ref_name,
            task_type=TaskType.EVENT
        )
        self._sink = deepcopy(event_prefix) + ':' + deepcopy(event_suffix)

    def to_workflow_task(self) -> WorkflowTask:
        workflow_task = super().to_workflow_task()
        workflow_task.sink = self._sink
        return workflow_task


class SqsEventTask(EventTaskInterface):
    def __init__(self, task_ref_name: str, queue_name: str) -> Self:
        super().__init__(task_ref_name, 'sqs', queue_name)


class ConductorEventTask(EventTaskInterface):
    def __init__(self, task_ref_name: str, event_name: str) -> Self:
        super().__init__(task_ref_name, 'conductor', event_name)



from copy import deepcopy
from typing import Any, Dict
from typing_extensions import Self


class KafkaPublishInput:
    def __init__(self,
                 bootstrap_servers: str = None,
                 key: str = None,
                 key_serializer: str = None,
                 value: str = None,
                 request_timeout_ms: str = None,
                 max_block_ms: str = None,
                 headers: Dict[str, Any] = None,
                 topic: str = None) -> Self:
        self._bootstrap_servers = deepcopy(bootstrap_servers)
        self._key = deepcopy(key)
        self._key_serializer = deepcopy(key_serializer)
        self._value = deepcopy(value)
        self._request_timeout_ms = deepcopy(request_timeout_ms)
        self._max_block_ms = deepcopy(max_block_ms)
        self. _headers = deepcopy(headers)
        self._topic = deepcopy(topic)



import pprint
import re  # noqa: F401

import six

class Workflow(object):
    """NOTE: This class is auto generated by the swagger code generator program.

    Do not edit the class manually.
    """
    """
    Attributes:
      swagger_types (dict): The key is attribute name
                            and the value is attribute type.
      attribute_map (dict): The key is attribute name
                            and the value is json key in definition.
    """
    swagger_types = {
        'owner_app': 'str',
        'create_time': 'int',
        'update_time': 'int',
        'created_by': 'str',
        'updated_by': 'str',
        'status': 'str',
        'end_time': 'int',
        'workflow_id': 'str',
        'parent_workflow_id': 'str',
        'parent_workflow_task_id': 'str',
        'tasks': 'list[Task]',
        'input': 'dict(str, object)',
        'output': 'dict(str, object)',
        'correlation_id': 'str',
        're_run_from_workflow_id': 'str',
        'reason_for_incompletion': 'str',
        'event': 'str',
        'task_to_domain': 'dict(str, str)',
        'failed_reference_task_names': 'list[str]',
        'workflow_definition': 'WorkflowDef',
        'external_input_payload_storage_path': 'str',
        'external_output_payload_storage_path': 'str',
        'priority': 'int',
        'variables': 'dict(str, object)',
        'last_retried_time': 'int',
        'start_time': 'int',
        'workflow_name': 'str',
        'workflow_version': 'int'
    }

    attribute_map = {
        'owner_app': 'ownerApp',
        'create_time': 'createTime',
        'update_time': 'updateTime',
        'created_by': 'createdBy',
        'updated_by': 'updatedBy',
        'status': 'status',
        'end_time': 'endTime',
        'workflow_id': 'workflowId',
        'parent_workflow_id': 'parentWorkflowId',
        'parent_workflow_task_id': 'parentWorkflowTaskId',
        'tasks': 'tasks',
        'input': 'input',
        'output': 'output',
        'correlation_id': 'correlationId',
        're_run_from_workflow_id': 'reRunFromWorkflowId',
        'reason_for_incompletion': 'reasonForIncompletion',
        'event': 'event',
        'task_to_domain': 'taskToDomain',
        'failed_reference_task_names': 'failedReferenceTaskNames',
        'workflow_definition': 'workflowDefinition',
        'external_input_payload_storage_path': 'externalInputPayloadStoragePath',
        'external_output_payload_storage_path': 'externalOutputPayloadStoragePath',
        'priority': 'priority',
        'variables': 'variables',
        'last_retried_time': 'lastRetriedTime',
        'start_time': 'startTime',
        'workflow_name': 'workflowName',
        'workflow_version': 'workflowVersion'
    }

    def __init__(self, owner_app=None, create_time=None, update_time=None, created_by=None, updated_by=None, status=None, end_time=None, workflow_id=None, parent_workflow_id=None, parent_workflow_task_id=None, tasks=None, input=None, output=None, correlation_id=None, re_run_from_workflow_id=None, reason_for_incompletion=None, event=None, task_to_domain=None, failed_reference_task_names=None, workflow_definition=None, external_input_payload_storage_path=None, external_output_payload_storage_path=None, priority=None, variables=None, last_retried_time=None, start_time=None, workflow_name=None, workflow_version=None):  # noqa: E501
        """Workflow - a model defined in Swagger"""  # noqa: E501
        self._owner_app = None
        self._create_time = None
        self._update_time = None
        self._created_by = None
        self._updated_by = None
        self._status = None
        self._end_time = None
        self._workflow_id = None
        self._parent_workflow_id = None
        self._parent_workflow_task_id = None
        self._tasks = None
        self._input = None
        self._output = None
        self._correlation_id = None
        self._re_run_from_workflow_id = None
        self._reason_for_incompletion = None
        self._event = None
        self._task_to_domain = None
        self._failed_reference_task_names = None
        self._workflow_definition = None
        self._external_input_payload_storage_path = None
        self._external_output_payload_storage_path = None
        self._priority = None
        self._variables = None
        self._last_retried_time = None
        self._start_time = None
        self._workflow_name = None
        self._workflow_version = None
        self.discriminator = None
        if owner_app is not None:
            self.owner_app = owner_app
        if create_time is not None:
            self.create_time = create_time
        if update_time is not None:
            self.update_time = update_time
        if created_by is not None:
            self.created_by = created_by
        if updated_by is not None:
            self.updated_by = updated_by
        if status is not None:
            self.status = status
        if end_time is not None:
            self.end_time = end_time
        if workflow_id is not None:
            self.workflow_id = workflow_id
        if parent_workflow_id is not None:
            self.parent_workflow_id = parent_workflow_id
        if parent_workflow_task_id is not None:
            self.parent_workflow_task_id = parent_workflow_task_id
        if tasks is not None:
            self.tasks = tasks
        if input is not None:
            self.input = input
        if output is not None:
            self.output = output
        if correlation_id is not None:
            self.correlation_id = correlation_id
        if re_run_from_workflow_id is not None:
            self.re_run_from_workflow_id = re_run_from_workflow_id
        if reason_for_incompletion is not None:
            self.reason_for_incompletion = reason_for_incompletion
        if event is not None:
            self.event = event
        if task_to_domain is not None:
            self.task_to_domain = task_to_domain
        if failed_reference_task_names is not None:
            self.failed_reference_task_names = failed_reference_task_names
        if workflow_definition is not None:
            self.workflow_definition = workflow_definition
        if external_input_payload_storage_path is not None:
            self.external_input_payload_storage_path = external_input_payload_storage_path
        if external_output_payload_storage_path is not None:
            self.external_output_payload_storage_path = external_output_payload_storage_path
        if priority is not None:
            self.priority = priority
        if variables is not None:
            self.variables = variables
        if last_retried_time is not None:
            self.last_retried_time = last_retried_time
        if start_time is not None:
            self.start_time = start_time
        if workflow_name is not None:
            self.workflow_name = workflow_name
        if workflow_version is not None:
            self.workflow_version = workflow_version

    @property
    def owner_app(self):
        """Gets the owner_app of this Workflow.  # noqa: E501


        :return: The owner_app of this Workflow.  # noqa: E501
        :rtype: str
        """
        return self._owner_app

    @owner_app.setter
    def owner_app(self, owner_app):
        """Sets the owner_app of this Workflow.


        :param owner_app: The owner_app of this Workflow.  # noqa: E501
        :type: str
        """

        self._owner_app = owner_app

    @property
    def create_time(self):
        """Gets the create_time of this Workflow.  # noqa: E501


        :return: The create_time of this Workflow.  # noqa: E501
        :rtype: int
        """
        return self._create_time

    @create_time.setter
    def create_time(self, create_time):
        """Sets the create_time of this Workflow.


        :param create_time: The create_time of this Workflow.  # noqa: E501
        :type: int
        """

        self._create_time = create_time

    @property
    def update_time(self):
        """Gets the update_time of this Workflow.  # noqa: E501


        :return: The update_time of this Workflow.  # noqa: E501
        :rtype: int
        """
        return self._update_time

    @update_time.setter
    def update_time(self, update_time):
        """Sets the update_time of this Workflow.


        :param update_time: The update_time of this Workflow.  # noqa: E501
        :type: int
        """

        self._update_time = update_time

    @property
    def created_by(self):
        """Gets the created_by of this Workflow.  # noqa: E501


        :return: The created_by of this Workflow.  # noqa: E501
        :rtype: str
        """
        return self._created_by

    @created_by.setter
    def created_by(self, created_by):
        """Sets the created_by of this Workflow.


        :param created_by: The created_by of this Workflow.  # noqa: E501
        :type: str
        """

        self._created_by = created_by

    @property
    def updated_by(self):
        """Gets the updated_by of this Workflow.  # noqa: E501


        :return: The updated_by of this Workflow.  # noqa: E501
        :rtype: str
        """
        return self._updated_by

    @updated_by.setter
    def updated_by(self, updated_by):
        """Sets the updated_by of this Workflow.


        :param updated_by: The updated_by of this Workflow.  # noqa: E501
        :type: str
        """

        self._updated_by = updated_by

    @property
    def status(self):
        """Gets the status of this Workflow.  # noqa: E501


        :return: The status of this Workflow.  # noqa: E501
        :rtype: str
        """
        return self._status

    @status.setter
    def status(self, status):
        """Sets the status of this Workflow.


        :param status: The status of this Workflow.  # noqa: E501
        :type: str
        """
        allowed_values = ["RUNNING", "COMPLETED", "FAILED", "TIMED_OUT", "TERMINATED", "PAUSED"]  # noqa: E501
        if status not in allowed_values:
            raise ValueError(
                "Invalid value for `status` ({0}), must be one of {1}"  # noqa: E501
                .format(status, allowed_values)
            )

        self._status = status

    @property
    def end_time(self):
        """Gets the end_time of this Workflow.  # noqa: E501


        :return: The end_time of this Workflow.  # noqa: E501
        :rtype: int
        """
        return self._end_time

    @end_time.setter
    def end_time(self, end_time):
        """Sets the end_time of this Workflow.


        :param end_time: The end_time of this Workflow.  # noqa: E501
        :type: int
        """

        self._end_time = end_time

    @property
    def workflow_id(self):
        """Gets the workflow_id of this Workflow.  # noqa: E501


        :return: The workflow_id of this Workflow.  # noqa: E501
        :rtype: str
        """
        return self._workflow_id

    @workflow_id.setter
    def workflow_id(self, workflow_id):
        """Sets the workflow_id of this Workflow.


        :param workflow_id: The workflow_id of this Workflow.  # noqa: E501
        :type: str
        """

        self._workflow_id = workflow_id

    @property
    def parent_workflow_id(self):
        """Gets the parent_workflow_id of this Workflow.  # noqa: E501


        :return: The parent_workflow_id of this Workflow.  # noqa: E501
        :rtype: str
        """
        return self._parent_workflow_id

    @parent_workflow_id.setter
    def parent_workflow_id(self, parent_workflow_id):
        """Sets the parent_workflow_id of this Workflow.


        :param parent_workflow_id: The parent_workflow_id of this Workflow.  # noqa: E501
        :type: str
        """

        self._parent_workflow_id = parent_workflow_id

    @property
    def parent_workflow_task_id(self):
        """Gets the parent_workflow_task_id of this Workflow.  # noqa: E501


        :return: The parent_workflow_task_id of this Workflow.  # noqa: E501
        :rtype: str
        """
        return self._parent_workflow_task_id

    @parent_workflow_task_id.setter
    def parent_workflow_task_id(self, parent_workflow_task_id):
        """Sets the parent_workflow_task_id of this Workflow.


        :param parent_workflow_task_id: The parent_workflow_task_id of this Workflow.  # noqa: E501
        :type: str
        """

        self._parent_workflow_task_id = parent_workflow_task_id

    @property
    def tasks(self):
        """Gets the tasks of this Workflow.  # noqa: E501


        :return: The tasks of this Workflow.  # noqa: E501
        :rtype: list[Task]
        """
        return self._tasks

    @tasks.setter
    def tasks(self, tasks):
        """Sets the tasks of this Workflow.


        :param tasks: The tasks of this Workflow.  # noqa: E501
        :type: list[Task]
        """

        self._tasks = tasks

    @property
    def input(self):
        """Gets the input of this Workflow.  # noqa: E501


        :return: The input of this Workflow.  # noqa: E501
        :rtype: dict(str, object)
        """
        return self._input

    @input.setter
    def input(self, input):
        """Sets the input of this Workflow.


        :param input: The input of this Workflow.  # noqa: E501
        :type: dict(str, object)
        """

        self._input = input

    @property
    def output(self):
        """Gets the output of this Workflow.  # noqa: E501


        :return: The output of this Workflow.  # noqa: E501
        :rtype: dict(str, object)
        """
        return self._output

    @output.setter
    def output(self, output):
        """Sets the output of this Workflow.


        :param output: The output of this Workflow.  # noqa: E501
        :type: dict(str, object)
        """

        self._output = output

    @property
    def correlation_id(self):
        """Gets the correlation_id of this Workflow.  # noqa: E501


        :return: The correlation_id of this Workflow.  # noqa: E501
        :rtype: str
        """
        return self._correlation_id

    @correlation_id.setter
    def correlation_id(self, correlation_id):
        """Sets the correlation_id of this Workflow.


        :param correlation_id: The correlation_id of this Workflow.  # noqa: E501
        :type: str
        """

        self._correlation_id = correlation_id

    @property
    def re_run_from_workflow_id(self):
        """Gets the re_run_from_workflow_id of this Workflow.  # noqa: E501


        :return: The re_run_from_workflow_id of this Workflow.  # noqa: E501
        :rtype: str
        """
        return self._re_run_from_workflow_id

    @re_run_from_workflow_id.setter
    def re_run_from_workflow_id(self, re_run_from_workflow_id):
        """Sets the re_run_from_workflow_id of this Workflow.


        :param re_run_from_workflow_id: The re_run_from_workflow_id of this Workflow.  # noqa: E501
        :type: str
        """

        self._re_run_from_workflow_id = re_run_from_workflow_id

    @property
    def reason_for_incompletion(self):
        """Gets the reason_for_incompletion of this Workflow.  # noqa: E501


        :return: The reason_for_incompletion of this Workflow.  # noqa: E501
        :rtype: str
        """
        return self._reason_for_incompletion

    @reason_for_incompletion.setter
    def reason_for_incompletion(self, reason_for_incompletion):
        """Sets the reason_for_incompletion of this Workflow.


        :param reason_for_incompletion: The reason_for_incompletion of this Workflow.  # noqa: E501
        :type: str
        """

        self._reason_for_incompletion = reason_for_incompletion

    @property
    def event(self):
        """Gets the event of this Workflow.  # noqa: E501


        :return: The event of this Workflow.  # noqa: E501
        :rtype: str
        """
        return self._event

    @event.setter
    def event(self, event):
        """Sets the event of this Workflow.


        :param event: The event of this Workflow.  # noqa: E501
        :type: str
        """

        self._event = event

    @property
    def task_to_domain(self):
        """Gets the task_to_domain of this Workflow.  # noqa: E501


        :return: The task_to_domain of this Workflow.  # noqa: E501
        :rtype: dict(str, str)
        """
        return self._task_to_domain

    @task_to_domain.setter
    def task_to_domain(self, task_to_domain):
        """Sets the task_to_domain of this Workflow.


        :param task_to_domain: The task_to_domain of this Workflow.  # noqa: E501
        :type: dict(str, str)
        """

        self._task_to_domain = task_to_domain

    @property
    def failed_reference_task_names(self):
        """Gets the failed_reference_task_names of this Workflow.  # noqa: E501


        :return: The failed_reference_task_names of this Workflow.  # noqa: E501
        :rtype: list[str]
        """
        return self._failed_reference_task_names

    @failed_reference_task_names.setter
    def failed_reference_task_names(self, failed_reference_task_names):
        """Sets the failed_reference_task_names of this Workflow.


        :param failed_reference_task_names: The failed_reference_task_names of this Workflow.  # noqa: E501
        :type: list[str]
        """

        self._failed_reference_task_names = failed_reference_task_names

    @property
    def workflow_definition(self):
        """Gets the workflow_definition of this Workflow.  # noqa: E501


        :return: The workflow_definition of this Workflow.  # noqa: E501
        :rtype: WorkflowDef
        """
        return self._workflow_definition

    @workflow_definition.setter
    def workflow_definition(self, workflow_definition):
        """Sets the workflow_definition of this Workflow.


        :param workflow_definition: The workflow_definition of this Workflow.  # noqa: E501
        :type: WorkflowDef
        """

        self._workflow_definition = workflow_definition

    @property
    def external_input_payload_storage_path(self):
        """Gets the external_input_payload_storage_path of this Workflow.  # noqa: E501


        :return: The external_input_payload_storage_path of this Workflow.  # noqa: E501
        :rtype: str
        """
        return self._external_input_payload_storage_path

    @external_input_payload_storage_path.setter
    def external_input_payload_storage_path(self, external_input_payload_storage_path):
        """Sets the external_input_payload_storage_path of this Workflow.


        :param external_input_payload_storage_path: The external_input_payload_storage_path of this Workflow.  # noqa: E501
        :type: str
        """

        self._external_input_payload_storage_path = external_input_payload_storage_path

    @property
    def external_output_payload_storage_path(self):
        """Gets the external_output_payload_storage_path of this Workflow.  # noqa: E501


        :return: The external_output_payload_storage_path of this Workflow.  # noqa: E501
        :rtype: str
        """
        return self._external_output_payload_storage_path

    @external_output_payload_storage_path.setter
    def external_output_payload_storage_path(self, external_output_payload_storage_path):
        """Sets the external_output_payload_storage_path of this Workflow.


        :param external_output_payload_storage_path: The external_output_payload_storage_path of this Workflow.  # noqa: E501
        :type: str
        """

        self._external_output_payload_storage_path = external_output_payload_storage_path

    @property
    def priority(self):
        """Gets the priority of this Workflow.  # noqa: E501


        :return: The priority of this Workflow.  # noqa: E501
        :rtype: int
        """
        return self._priority

    @priority.setter
    def priority(self, priority):
        """Sets the priority of this Workflow.


        :param priority: The priority of this Workflow.  # noqa: E501
        :type: int
        """

        self._priority = priority

    @property
    def variables(self):
        """Gets the variables of this Workflow.  # noqa: E501


        :return: The variables of this Workflow.  # noqa: E501
        :rtype: dict(str, object)
        """
        return self._variables

    @variables.setter
    def variables(self, variables):
        """Sets the variables of this Workflow.


        :param variables: The variables of this Workflow.  # noqa: E501
        :type: dict(str, object)
        """

        self._variables = variables

    @property
    def last_retried_time(self):
        """Gets the last_retried_time of this Workflow.  # noqa: E501


        :return: The last_retried_time of this Workflow.  # noqa: E501
        :rtype: int
        """
        return self._last_retried_time

    @last_retried_time.setter
    def last_retried_time(self, last_retried_time):
        """Sets the last_retried_time of this Workflow.


        :param last_retried_time: The last_retried_time of this Workflow.  # noqa: E501
        :type: int
        """

        self._last_retried_time = last_retried_time

    @property
    def start_time(self):
        """Gets the start_time of this Workflow.  # noqa: E501


        :return: The start_time of this Workflow.  # noqa: E501
        :rtype: int
        """
        return self._start_time

    @start_time.setter
    def start_time(self, start_time):
        """Sets the start_time of this Workflow.


        :param start_time: The start_time of this Workflow.  # noqa: E501
        :type: int
        """

        self._start_time = start_time

    @property
    def workflow_name(self):
        """Gets the workflow_name of this Workflow.  # noqa: E501


        :return: The workflow_name of this Workflow.  # noqa: E501
        :rtype: str
        """
        return self._workflow_name

    @workflow_name.setter
    def workflow_name(self, workflow_name):
        """Sets the workflow_name of this Workflow.


        :param workflow_name: The workflow_name of this Workflow.  # noqa: E501
        :type: str
        """

        self._workflow_name = workflow_name

    @property
    def workflow_version(self):
        """Gets the workflow_version of this Workflow.  # noqa: E501


        :return: The workflow_version of this Workflow.  # noqa: E501
        :rtype: int
        """
        return self._workflow_version

    @workflow_version.setter
    def workflow_version(self, workflow_version):
        """Sets the workflow_version of this Workflow.


        :param workflow_version: The workflow_version of this Workflow.  # noqa: E501
        :type: int
        """

        self._workflow_version = workflow_version

    def to_dict(self):
        """Returns the model properties as a dict"""
        result = {}

        for attr, _ in six.iteritems(self.swagger_types):
            value = getattr(self, attr)
            if isinstance(value, list):
                result[attr] = list(map(
                    lambda x: x.to_dict() if hasattr(x, "to_dict") else x,
                    value
                ))
            elif hasattr(value, "to_dict"):
                result[attr] = value.to_dict()
            elif isinstance(value, dict):
                result[attr] = dict(map(
                    lambda item: (item[0], item[1].to_dict())
                    if hasattr(item[1], "to_dict") else item,
                    value.items()
                ))
            else:
                result[attr] = value
        if issubclass(Workflow, dict):
            for key, value in self.items():
                result[key] = value

        return result

    def to_str(self):
        """Returns the string representation of the model"""
        return pprint.pformat(self.to_dict())

    def __repr__(self):
        """For `print` and `pprint`"""
        return self.to_str()

    def __eq__(self, other):
        """Returns true if both objects are equal"""
        if not isinstance(other, Workflow):
            return False

        return self.__dict__ == other.__dict__

    def __ne__(self, other):
        """Returns true if both objects are not equal"""
        return not self == other



from abc import ABC, abstractmethod
from conductor.client.http.models.workflow_task import WorkflowTask
from conductor.client.workflow.task.task_type import TaskType
from copy import deepcopy
from typing import Any, Dict, List
from typing_extensions import Self


def get_task_interface_list_as_workflow_task_list(*tasks: Self) -> List[WorkflowTask]:
    converted_tasks = []
    for task in tasks:
        converted_tasks.append(task.to_workflow_task())
    return converted_tasks


class TaskInterface(ABC):
    @abstractmethod
    def __init__(self,
                 task_reference_name: str,
                 task_type: TaskType,
                 task_name: str = None,
                 description: str = None,
                 optional: bool = None,
                 input_parameters: Dict[str, Any] = None) -> Self:
        self.task_reference_name = task_reference_name
        self.task_type = task_type
        self.name = task_name or task_reference_name
        self.description = description
        self.optional = optional
        self.input_parameters = input_parameters

    @property
    def task_reference_name(self) -> str:
        return self._task_reference_name

    @task_reference_name.setter
    def task_reference_name(self, task_reference_name: str) -> None:
        if not isinstance(task_reference_name, str):
            raise Exception('invalid type')
        self._task_reference_name = deepcopy(task_reference_name)

    @property
    def task_type(self) -> TaskType:
        return self._task_type

    @task_type.setter
    def task_type(self, task_type: TaskType) -> None:
        if not isinstance(task_type, TaskType):
            raise Exception('invalid type')
        self._task_type = deepcopy(task_type)

    @property
    def name(self) -> str:
        return self._name

    @name.setter
    def name(self, name: str) -> None:
        if not isinstance(name, str):
            raise Exception('invalid type')
        self._name = name

    @property
    def description(self) -> str:
        return self._description

    @description.setter
    def description(self, description: str) -> None:
        if description != None and not isinstance(description, str):
            raise Exception('invalid type')
        self._description = deepcopy(description)

    @property
    def optional(self) -> bool:
        return self._optional

    @optional.setter
    def optional(self, optional: bool) -> None:
        if optional != None and not isinstance(optional, bool):
            raise Exception('invalid type')
        self._optional = deepcopy(optional)

    @property
    def input_parameters(self) -> Dict[str, Any]:
        return self._input_parameters

    @input_parameters.setter
    def input_parameters(self, input_parameters: Dict[str, Any]) -> None:
        if input_parameters == None:
            self._input_parameters = {}
            return
        if not isinstance(input_parameters, dict):
            raise Exception('invalid type')
        for key in input_parameters.keys():
            if not isinstance(key, str):
                raise Exception('invalid type')
        self._input_parameters = deepcopy(input_parameters)

    def input(self, key: str, value: Any) -> Self:
        if not isinstance(key, str):
            raise Exception('invalid type')
        self._input_parameters[key] = deepcopy(value)
        return self

    def to_workflow_task(self) -> WorkflowTask:
        return WorkflowTask(
            name=self._name,
            task_reference_name=self._task_reference_name,
            workflow_task_type=self._task_type.value,
            description=self._description,
            input_parameters=self._input_parameters,
            optional=self._optional,
        )

    def output_ref(self, path: str) -> str:
        if path == '':
            return f'${{{self._task_reference_name}.output}}'
        return f'${{{self._task_reference_name}.output.{path}}}'



from typing import List
from conductor.client.http.models.workflow_task import WorkflowTask
from conductor.client.workflow.task.join_task import JoinTask
from conductor.client.workflow.task.task import TaskInterface
from conductor.client.workflow.task.task_type import TaskType
from copy import deepcopy
from typing_extensions import Self


class DynamicForkTask(TaskInterface):
    def __init__(self, task_ref_name: str, pre_fork_task: TaskInterface, join_task: JoinTask = None) -> Self:
        super().__init__(
            task_reference_name=task_ref_name,
            task_type=TaskType.FORK_JOIN_DYNAMIC
        )
        self._pre_fork_task = deepcopy(pre_fork_task)
        self._join_task = deepcopy(join_task)

    def to_workflow_task(self) -> WorkflowTask:
        workflow = super().to_workflow_task()
        workflow.dynamic_fork_join_tasks_param = 'forkedTasks'
        workflow.dynamic_fork_tasks_input_param_name = 'forkedTasksInputs'
        workflow.input_parameters['forkedTasks'] = self._pre_fork_task.output_ref(
            'forkedTasks'
        )
        workflow.input_parameters['forkedTasksInputs'] = self._pre_fork_task.output_ref(
            'forkedTasksInputs'
        )
        tasks = [
            self._pre_fork_task.to_workflow_task(),
            workflow,
        ]
        if self._join_task != None:
            tasks.append(self._join_task.to_workflow_task())
        return tasks



from enum import Enum


class MetricName(str, Enum):
    EXTERNAL_PAYLOAD_USED = "external_payload_used"
    TASK_ACK_ERROR = "task_ack_error"
    TASK_ACK_FAILED = "task_ack_failed"
    TASK_EXECUTE_ERROR = "task_execute_error"
    TASK_EXECUTE_TIME = "task_execute_time"
    TASK_EXECUTION_QUEUE_FULL = "task_execution_queue_full"
    TASK_PAUSED = "task_paused"
    TASK_POLL = "task_poll"
    TASK_POLL_ERROR = "task_poll_error"
    TASK_POLL_TIME = "task_poll_time"
    TASK_RESULT_SIZE = "task_result_size"
    TASK_UPDATE_ERROR = "task_update_error"
    THREAD_UNCAUGHT_EXCEPTION = "thread_uncaught_exceptions"
    WORKFLOW_INPUT_SIZE = "workflow_input_size"
    WORKFLOW_START_ERROR = "workflow_start_error"



from conductor.client.workflow.task.task import TaskInterface
from conductor.client.workflow.task.task_type import TaskType
from typing_extensions import Self


class JsonJQTask(TaskInterface):
    def __init__(self, task_ref_name: str, script: str) -> Self:
        super().__init__(
            task_reference_name=task_ref_name,
            task_type=TaskType.JSON_JQ_TRANSFORM,
            input_parameters={
                "queryExpression": script
            }
        )



import pprint
import re  # noqa: F401

import six

class WorkflowScheduleExecutionModel(object):
    """NOTE: This class is auto generated by the swagger code generator program.

    Do not edit the class manually.
    """
    """
    Attributes:
      swagger_types (dict): The key is attribute name
                            and the value is attribute type.
      attribute_map (dict): The key is attribute name
                            and the value is json key in definition.
    """
    swagger_types = {
        'execution_id': 'str',
        'schedule_name': 'str',
        'scheduled_time': 'int',
        'execution_time': 'int',
        'workflow_name': 'str',
        'workflow_id': 'str',
        'reason': 'str',
        'stack_trace': 'str',
        'start_workflow_request': 'StartWorkflowRequest',
        'state': 'str'
    }

    attribute_map = {
        'execution_id': 'executionId',
        'schedule_name': 'scheduleName',
        'scheduled_time': 'scheduledTime',
        'execution_time': 'executionTime',
        'workflow_name': 'workflowName',
        'workflow_id': 'workflowId',
        'reason': 'reason',
        'stack_trace': 'stackTrace',
        'start_workflow_request': 'startWorkflowRequest',
        'state': 'state'
    }

    def __init__(self, execution_id=None, schedule_name=None, scheduled_time=None, execution_time=None, workflow_name=None, workflow_id=None, reason=None, stack_trace=None, start_workflow_request=None, state=None):  # noqa: E501
        """WorkflowScheduleExecutionModel - a model defined in Swagger"""  # noqa: E501
        self._execution_id = None
        self._schedule_name = None
        self._scheduled_time = None
        self._execution_time = None
        self._workflow_name = None
        self._workflow_id = None
        self._reason = None
        self._stack_trace = None
        self._start_workflow_request = None
        self._state = None
        self.discriminator = None
        if execution_id is not None:
            self.execution_id = execution_id
        if schedule_name is not None:
            self.schedule_name = schedule_name
        if scheduled_time is not None:
            self.scheduled_time = scheduled_time
        if execution_time is not None:
            self.execution_time = execution_time
        if workflow_name is not None:
            self.workflow_name = workflow_name
        if workflow_id is not None:
            self.workflow_id = workflow_id
        if reason is not None:
            self.reason = reason
        if stack_trace is not None:
            self.stack_trace = stack_trace
        if start_workflow_request is not None:
            self.start_workflow_request = start_workflow_request
        if state is not None:
            self.state = state

    @property
    def execution_id(self):
        """Gets the execution_id of this WorkflowScheduleExecutionModel.  # noqa: E501


        :return: The execution_id of this WorkflowScheduleExecutionModel.  # noqa: E501
        :rtype: str
        """
        return self._execution_id

    @execution_id.setter
    def execution_id(self, execution_id):
        """Sets the execution_id of this WorkflowScheduleExecutionModel.


        :param execution_id: The execution_id of this WorkflowScheduleExecutionModel.  # noqa: E501
        :type: str
        """

        self._execution_id = execution_id

    @property
    def schedule_name(self):
        """Gets the schedule_name of this WorkflowScheduleExecutionModel.  # noqa: E501


        :return: The schedule_name of this WorkflowScheduleExecutionModel.  # noqa: E501
        :rtype: str
        """
        return self._schedule_name

    @schedule_name.setter
    def schedule_name(self, schedule_name):
        """Sets the schedule_name of this WorkflowScheduleExecutionModel.


        :param schedule_name: The schedule_name of this WorkflowScheduleExecutionModel.  # noqa: E501
        :type: str
        """

        self._schedule_name = schedule_name

    @property
    def scheduled_time(self):
        """Gets the scheduled_time of this WorkflowScheduleExecutionModel.  # noqa: E501


        :return: The scheduled_time of this WorkflowScheduleExecutionModel.  # noqa: E501
        :rtype: int
        """
        return self._scheduled_time

    @scheduled_time.setter
    def scheduled_time(self, scheduled_time):
        """Sets the scheduled_time of this WorkflowScheduleExecutionModel.


        :param scheduled_time: The scheduled_time of this WorkflowScheduleExecutionModel.  # noqa: E501
        :type: int
        """

        self._scheduled_time = scheduled_time

    @property
    def execution_time(self):
        """Gets the execution_time of this WorkflowScheduleExecutionModel.  # noqa: E501


        :return: The execution_time of this WorkflowScheduleExecutionModel.  # noqa: E501
        :rtype: int
        """
        return self._execution_time

    @execution_time.setter
    def execution_time(self, execution_time):
        """Sets the execution_time of this WorkflowScheduleExecutionModel.


        :param execution_time: The execution_time of this WorkflowScheduleExecutionModel.  # noqa: E501
        :type: int
        """

        self._execution_time = execution_time

    @property
    def workflow_name(self):
        """Gets the workflow_name of this WorkflowScheduleExecutionModel.  # noqa: E501


        :return: The workflow_name of this WorkflowScheduleExecutionModel.  # noqa: E501
        :rtype: str
        """
        return self._workflow_name

    @workflow_name.setter
    def workflow_name(self, workflow_name):
        """Sets the workflow_name of this WorkflowScheduleExecutionModel.


        :param workflow_name: The workflow_name of this WorkflowScheduleExecutionModel.  # noqa: E501
        :type: str
        """

        self._workflow_name = workflow_name

    @property
    def workflow_id(self):
        """Gets the workflow_id of this WorkflowScheduleExecutionModel.  # noqa: E501


        :return: The workflow_id of this WorkflowScheduleExecutionModel.  # noqa: E501
        :rtype: str
        """
        return self._workflow_id

    @workflow_id.setter
    def workflow_id(self, workflow_id):
        """Sets the workflow_id of this WorkflowScheduleExecutionModel.


        :param workflow_id: The workflow_id of this WorkflowScheduleExecutionModel.  # noqa: E501
        :type: str
        """

        self._workflow_id = workflow_id

    @property
    def reason(self):
        """Gets the reason of this WorkflowScheduleExecutionModel.  # noqa: E501


        :return: The reason of this WorkflowScheduleExecutionModel.  # noqa: E501
        :rtype: str
        """
        return self._reason

    @reason.setter
    def reason(self, reason):
        """Sets the reason of this WorkflowScheduleExecutionModel.


        :param reason: The reason of this WorkflowScheduleExecutionModel.  # noqa: E501
        :type: str
        """

        self._reason = reason

    @property
    def stack_trace(self):
        """Gets the stack_trace of this WorkflowScheduleExecutionModel.  # noqa: E501


        :return: The stack_trace of this WorkflowScheduleExecutionModel.  # noqa: E501
        :rtype: str
        """
        return self._stack_trace

    @stack_trace.setter
    def stack_trace(self, stack_trace):
        """Sets the stack_trace of this WorkflowScheduleExecutionModel.


        :param stack_trace: The stack_trace of this WorkflowScheduleExecutionModel.  # noqa: E501
        :type: str
        """

        self._stack_trace = stack_trace

    @property
    def start_workflow_request(self):
        """Gets the start_workflow_request of this WorkflowScheduleExecutionModel.  # noqa: E501


        :return: The start_workflow_request of this WorkflowScheduleExecutionModel.  # noqa: E501
        :rtype: StartWorkflowRequest
        """
        return self._start_workflow_request

    @start_workflow_request.setter
    def start_workflow_request(self, start_workflow_request):
        """Sets the start_workflow_request of this WorkflowScheduleExecutionModel.


        :param start_workflow_request: The start_workflow_request of this WorkflowScheduleExecutionModel.  # noqa: E501
        :type: StartWorkflowRequest
        """

        self._start_workflow_request = start_workflow_request

    @property
    def state(self):
        """Gets the state of this WorkflowScheduleExecutionModel.  # noqa: E501


        :return: The state of this WorkflowScheduleExecutionModel.  # noqa: E501
        :rtype: str
        """
        return self._state

    @state.setter
    def state(self, state):
        """Sets the state of this WorkflowScheduleExecutionModel.


        :param state: The state of this WorkflowScheduleExecutionModel.  # noqa: E501
        :type: str
        """
        allowed_values = ["POLLED", "FAILED", "EXECUTED"]  # noqa: E501
        if state not in allowed_values:
            raise ValueError(
                "Invalid value for `state` ({0}), must be one of {1}"  # noqa: E501
                .format(state, allowed_values)
            )

        self._state = state

    def to_dict(self):
        """Returns the model properties as a dict"""
        result = {}

        for attr, _ in six.iteritems(self.swagger_types):
            value = getattr(self, attr)
            if isinstance(value, list):
                result[attr] = list(map(
                    lambda x: x.to_dict() if hasattr(x, "to_dict") else x,
                    value
                ))
            elif hasattr(value, "to_dict"):
                result[attr] = value.to_dict()
            elif isinstance(value, dict):
                result[attr] = dict(map(
                    lambda item: (item[0], item[1].to_dict())
                    if hasattr(item[1], "to_dict") else item,
                    value.items()
                ))
            else:
                result[attr] = value
        if issubclass(WorkflowScheduleExecutionModel, dict):
            for key, value in self.items():
                result[key] = value

        return result

    def to_str(self):
        """Returns the string representation of the model"""
        return pprint.pformat(self.to_dict())

    def __repr__(self):
        """For `print` and `pprint`"""
        return self.to_str()

    def __eq__(self, other):
        """Returns true if both objects are equal"""
        if not isinstance(other, WorkflowScheduleExecutionModel):
            return False

        return self.__dict__ == other.__dict__

    def __ne__(self, other):
        """Returns true if both objects are not equal"""
        return not self == other



from conductor.client.configuration.configuration import Configuration
from pathlib import Path
import logging
import os

logger = logging.getLogger(
    Configuration.get_logging_formatted_name(
        __name__
    )
)


def get_default_temporary_folder() -> str:
    return f'{str(Path.home())}/tmp/'


class MetricsSettings:
    def __init__(
            self,
            directory: str = None,
            file_name: str = 'metrics.log',
            update_interval: float = 0.1):
        if directory == None:
            directory = get_default_temporary_folder()
        self.__set_dir(directory)
        self.file_name = file_name
        self.update_interval = update_interval

    def __set_dir(self, dir: str) -> None:
        if not os.path.isdir(dir):
            try:
                os.mkdir(dir)
            except Exception as e:
                logger.warning(
                    'Failed to create metrics temporary folder, reason: ', e)
        self.directory = dir



from conductor.client.http.models.workflow_task import WorkflowTask
from conductor.client.workflow.task.task import TaskInterface
from conductor.client.workflow.task.task_type import TaskType
from copy import deepcopy
from typing import List
from typing_extensions import Self


def get_join_task(task_reference_name: str) -> str:
    return task_reference_name + '_join'


class ForkTask(TaskInterface):
    def __init__(self, task_ref_name: str, forked_tasks: List[List[TaskInterface]]) -> Self:
        super().__init__(
            task_reference_name=task_ref_name,
            task_type=TaskType.FORK_JOIN
        )
        self._forked_tasks = deepcopy(forked_tasks)

    def to_workflow_task(self) -> WorkflowTask:
        workflow_task = super().to_workflow_task()
        workflow_task.fork_tasks = []
        workflow_task.join_on = []
        for inner_forked_tasks in self._forked_tasks:
            converted_inner_forked_tasks = []
            for inner_forked_task in inner_forked_tasks:
                converted_inner_forked_tasks.append(
                    inner_forked_task.to_workflow_task()
                )
            workflow_task.fork_tasks.append(converted_inner_forked_tasks)
            workflow_task.join_on.append(
                get_join_task(
                    converted_inner_forked_tasks[-1].task_reference_name)
            )
        return workflow_task



from copy import deepcopy
from conductor.client.http.models.task import Task
from conductor.client.http.models.task_result import TaskResult
from conductor.client.http.models.task_result_status import TaskResultStatus
from conductor.client.worker.worker_interface import WorkerInterface
from typing import Any, Callable, Union
from typing_extensions import Self
import inspect

ExecuteTaskFunction = Callable[
    [
        Union[Task, object]
    ],
    Union[TaskResult, object]
]


def is_callable_input_parameter_a_task(callable: ExecuteTaskFunction, object_type: Any) -> bool:
    parameters = inspect.signature(callable).parameters
    if len(parameters) != 1:
        return False
    parameter = parameters[list(parameters.keys())[0]]
    return parameter.annotation == object_type


def is_callable_return_value_of_type(callable: ExecuteTaskFunction, object_type: Any) -> bool:
    return_annotation = inspect.signature(callable).return_annotation
    return return_annotation == object_type


class Worker(WorkerInterface):
    def __init__(self,
                 task_definition_name: str,
                 execute_function: ExecuteTaskFunction,
                 poll_interval: float = None,
                 domain: str = None,
                 ) -> Self:
        super().__init__(task_definition_name)
        if poll_interval == None:
            poll_interval = super().get_polling_interval_in_seconds()
        self.poll_interval = deepcopy(poll_interval)
        if domain == None:
            domain = super().get_domain()
        self.domain = deepcopy(domain)
        self.execute_function = deepcopy(execute_function)

    def execute(self, task: Task) -> TaskResult:
        execute_function_input = None
        if self._is_execute_function_input_parameter_a_task:
            execute_function_input = task
        else:
            execute_function_input = task.input_data
        if self._is_execute_function_return_value_a_task_result:
            execute_function_output = self.execute_function(
                execute_function_input)
            if type(execute_function_output) == TaskResult:
                execute_function_output.task_id = task.task_id
                execute_function_output.workflow_instance_id = task.workflow_instance_id
            return execute_function_output
        task_result = self.get_task_result_from_task(task)
        task_result.status = TaskResultStatus.COMPLETED
        task_result.output_data = self.execute_function(task)
        return task_result

    def get_polling_interval_in_seconds(self) -> float:
        return self.poll_interval

    def get_domain(self) -> str:
        return self.domain

    @property
    def execute_function(self) -> ExecuteTaskFunction:
        return self._execute_function

    @execute_function.setter
    def execute_function(self, execute_function: ExecuteTaskFunction) -> None:
        self._execute_function = execute_function
        self._is_execute_function_input_parameter_a_task = is_callable_input_parameter_a_task(
            callable=execute_function,
            object_type=Task,
        )
        self._is_execute_function_return_value_a_task_result = is_callable_return_value_of_type(
            callable=execute_function,
            object_type=TaskResult,
        )
